@@ -15,7 +15,7 @@
 # limitations under the License.
 #
 
-''' Definitions needed for events. See :ref:`Events` for info on how to use it.'''
+""" Definitions needed for events. See :ref:`Events` for info on how to use it."""
 
 
 class Event(object):
@@ -25,6 +25,10 @@ class Event(object):
     DEPENDENCY_PRESENT = "event.core.dependency.present"
     BROKEN_TASK = "event.core.task.broken"
     START = "event.core.start"
+    #: This event can be fired by the task itself while running. The purpose is
+    #: for the task to report progress, metadata or any generic info so that
+    #: event handler listening for this can keep track of the progress of running task.
+    PROGRESS = "event.core.progress"
     FAILURE = "event.core.failure"
     SUCCESS = "event.core.success"
     PROCESSING_TIME = "event.core.processing_time"
